MDPax
=====

.. include:: ../../README.md
   :start-after: # MDPax
   :end-before: ## Overview
   :parser: myst_parser.sphinx_

Overview
--------
.. include:: ../../README.md
   :start-after: ## Overview
   :end-before: ## Installation
   :parser: myst_parser.sphinx_

Installation
------------
.. include:: ../../README.md
   :start-after: ## Installation
   :end-before: ## Quick Start
   :parser: myst_parser.sphinx_

Quick Start
-----------
.. include:: ../../README.md
   :start-after: ## Quick Start
   :end-before: ## Documentation
   :parser: myst_parser.sphinx_

Citation
--------
.. include:: ../../README.md
   :start-after: ## Citation
   :end-before: ## License
   :parser: myst_parser.sphinx_

License
-------
.. include:: ../../README.md
   :start-after: ## License
   :end-before: ## Related Projects
   :parser: myst_parser.sphinx_

Related Projects
-----------------
.. include:: ../../README.md
   :start-after: ## Related Projects
   :end-before: ## Acknowledgments
   :parser: myst_parser.sphinx_

Acknowledgments
---------------
.. include:: ../../README.md
   :start-after: ## Acknowledgments
   :parser: myst_parser.sphinx_

.. toctree::
   :maxdepth: 2
   :caption: Contents
   :hidden:

   notebooks/getting_started.ipynb
   notebooks/create_custom_problem.ipynb
   api
   development
   contributing

  
